[llvm] r264319 - Minor cosmestic changes (NFC)

Sanjoy Das via llvm-commits llvm-commits at lists.llvm.org
Thu Mar 24 11:57:32 PDT 2016


Author: sanjoy
Date: Thu Mar 24 13:57:31 2016
New Revision: 264319

URL: http://llvm.org/viewvc/llvm-project?rev=264319&view=rev
Log:
Minor cosmestic changes (NFC)

 - Reflow comments
 - Rename function

Modified:
    llvm/trunk/include/llvm/CodeGen/FunctionLoweringInfo.h
    llvm/trunk/lib/CodeGen/SelectionDAG/StatepointLowering.cpp

Modified: llvm/trunk/include/llvm/CodeGen/FunctionLoweringInfo.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/CodeGen/FunctionLoweringInfo.h?rev=264319&r1=264318&r2=264319&view=diff
==============================================================================
--- llvm/trunk/include/llvm/CodeGen/FunctionLoweringInfo.h (original)
+++ llvm/trunk/include/llvm/CodeGen/FunctionLoweringInfo.h Thu Mar 24 13:57:31 2016
@@ -80,12 +80,11 @@ public:
   /// Track virtual registers created for exception pointers.
   DenseMap<const Value *, unsigned> CatchPadExceptionPointers;
 
-  // Keep track of frame indices allocated for statepoints as they could be used
-  // across basic block boundaries.
-  // Key of the map is statepoint instruction, value is a map from spilled
-  // llvm Value to the optional stack stack slot index.
-  // If optional is unspecified it means that we have visited this value
-  // but didn't spill it.
+  /// Keep track of frame indices allocated for statepoints as they could be
+  /// used across basic block boundaries.  Key of the map is statepoint
+  /// instruction, value is a map from spilled llvm Value to the optional stack
+  /// stack slot index.  If optional is unspecified it means that we have
+  /// visited this value but didn't spill it.
   typedef DenseMap<const Value*, Optional<int>> StatepointSpilledValueMapTy;
   DenseMap<const Instruction*, StatepointSpilledValueMapTy>
     StatepointRelocatedValues;

Modified: llvm/trunk/lib/CodeGen/SelectionDAG/StatepointLowering.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/SelectionDAG/StatepointLowering.cpp?rev=264319&r1=264318&r2=264319&view=diff
==============================================================================
--- llvm/trunk/lib/CodeGen/SelectionDAG/StatepointLowering.cpp (original)
+++ llvm/trunk/lib/CodeGen/SelectionDAG/StatepointLowering.cpp Thu Mar 24 13:57:31 2016
@@ -246,10 +246,10 @@ static void reservePreviousStackSlotForV
 /// StackMap section.  It has no effect on the number of spill slots required
 /// or the actual lowering.
 static void
-removeDuplicatesGCPtrs(SmallVectorImpl<const Value *> &Bases,
-                       SmallVectorImpl<const Value *> &Ptrs,
-                       SmallVectorImpl<const GCRelocateInst *> &Relocs,
-                       SelectionDAGBuilder &Builder) {
+removeDuplicateGCPtrs(SmallVectorImpl<const Value *> &Bases,
+                      SmallVectorImpl<const Value *> &Ptrs,
+                      SmallVectorImpl<const GCRelocateInst *> &Relocs,
+                      SelectionDAGBuilder &Builder) {
 
   // This is horribly inefficient, but I don't care right now
   SmallSet<SDValue, 32> Seen;
@@ -540,8 +540,8 @@ SDValue SelectionDAGBuilder::LowerAsSTAT
   StatepointLowering.startNewStatepoint(*this);
 
 #ifndef NDEBUG
   // We schedule gc relocates before removeDuplicatesGCPtrs since we _will_
   // encounter the duplicate gc relocates we elide in removeDuplicatesGCPtrs.
   for (auto *Reloc : SI.GCRelocates)
     if (Reloc->getParent() == SI.StatepointInstr->getParent())
       StatepointLowering.scheduleRelocCall(*Reloc);
@@ -551,7 +551,7 @@ SDValue SelectionDAGBuilder::LowerAsSTAT
   // input.  Also has the effect of removing duplicates in the original
   // llvm::Value input list as well.  This is a useful optimization for
   // reducing the size of the StackMap section.  It has no other impact.
-  removeDuplicatesGCPtrs(SI.Bases, SI.Ptrs, SI.GCRelocates, *this);
+  removeDuplicateGCPtrs(SI.Bases, SI.Ptrs, SI.GCRelocates, *this);
   assert(SI.Bases.size() == SI.Ptrs.size() &&
          SI.Ptrs.size() == SI.GCRelocates.size());
 
@@ -540,8 +540,8 @@ SDValue SelectionDAGBuilder::LowerAsSTAT
 
 #ifndef NDEBUG
-  // We schedule gc relocates before removeDuplicatesGCPtrs since we _will_
-  // encounter the duplicate gc relocates we elide in removeDuplicatesGCPtrs.
+  // We schedule gc relocates before removeDuplicateGCPtrs since we _will_
+  // encounter the duplicate gc relocates we elide in removeDuplicateGCPtrs.
   for (auto *Reloc : SI.GCRelocates)
     if (Reloc->getParent() == SI.StatepointInstr->getParent())




More information about the llvm-commits mailing list